<?php

/**
 * @file
 * Admin only functionality for the peerjs module.
 */

/**
 * Menu form callback; Display the peerjs admin form.
 */
function peerjs_admin_form($form, $form_state) {
  $form = array();
  $settings = variable_get('peerjs');

  $form['peerjs'] = array(
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#title' => t('Default Server'),
  );
  $form['peerjs']['choice'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow users to choose server?'),
    '#default_value' => $settings['choice'],
  );
  $form['peerjs']['host'] = array(
    '#type' => 'textfield',
    '#title' => t('Host'),
    '#description' => t('Enter the server address of the peer server. Defaults to localhost.'),
    '#default_value' => $settings['host'],
  );
  $form['peerjs']['port'] = array(
    '#type' => 'textfield',
    '#title' => t('Port'),
    '#description' => t('Enter the server port of the peer server. Defaults to 80.'),
    '#default_value' => $settings['port'],
  );
  $form['peerjs']['path2app'] = array(
    '#type' => 'textfield',
    '#title' => t('Path to Application'),
    '#description' => t('Enter the server port of the peer server. Defaults to /.'),
    '#default_value' => $settings['path2app'],
  );
  $form['peerjs']['constraints'] = array(
    '#type' => 'fieldset',
    '#tree' => TRUE,
    '#title' => t('getUserMedia Contraints'),
  );
  $form['peerjs']['constraints']['audio'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Audio'),
    '#options' => array(
      0 => 'Disabled',
      1 => 'Enabled',
    ),
    '#default_value' => $settings['constraints']['audio'],
  );
  $form['peerjs']['constraints']['video'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Video'),
    '#options' => array(
      0 => 'Disabled',
      1 => 'Enabled',
    ),
    '#default_value' => $settings['constraints']['video'],
  );

  return system_settings_form($form);
}

/**
 * Form constructor for the peerjs_chat add/edit form.
 *
 * @see peerjs_chat_form_validate()
 * @see peerjs_chat_form_submit()
 * @see peerjs_chat_form_delete_submit()
 * @ingroup forms
 */
function peerjs_chat_form($form, &$form_state, $entity) {
  $settings = variable_get('peerjs');

  $form['peerjs_chat'] = array(
    '#type' => 'value',
    '#value' => $entity,
  );
  $form['label'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#required' => TRUE,
    '#default_value' => !empty($entity->label) ? $entity->label : '',
    '#maxlength' => 255,
  );

  if ($settings['choice']) {
    $form['server'] = array(
      '#type' => 'fieldset',
      '#title' => t('Default Server'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $form['server']['host'] = array(
      '#type' => 'textfield',
      '#title' => t('Host'),
      '#description' => t('Enter the server address of the peer server. Defaults to localhost.'),
      '#default_value' => !empty($entity->host) ? $entity->host : $settings['host'],
    );
    $form['server']['port'] = array(
      '#type' => 'textfield',
      '#title' => t('Port'),
      '#description' => t('Enter the server port of the peer server. Leave blank to automatically choose port (80 or 443).'),
      '#default_value' => !empty($entity->port) ? $entity->port : $settings['port'],
    );
    $form['server']['path2app'] = array(
      '#type' => 'textfield',
      '#title' => t('Path to Application'),
      '#description' => t('Enter the application path of the peer server. Defaults to /.'),
      '#default_value' => !empty($entity->path2app) ? $entity->path2app : $settings['path2app'],
    );
  }
  else {
    $form['host'] = array(
      '#type' => 'hidden',
      '#default_value' => !empty($entity->host) ? $entity->host : $settings['host'],
    );
    $form['port'] = array(
      '#type' => 'hidden',
      '#default_value' => !empty($entity->port) ? $entity->port : $settings['port'],
    );
    $form['path2app'] = array(
      '#type' => 'hidden',
      '#default_value' => !empty($entity->path2app) ? $entity->path2app : $settings['path2app'],
    );
  }

  field_attach_form('peerjs_chat', $entity, $form, $form_state);

  $form['actions'] = array('#type' => 'actions');
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  if (!empty($entity->cid) && peerjs_chat_access('delete', $entity)) {
    $form['actions']['delete'] = array(
      '#type' => 'submit',
      '#value' => t('Delete'),
      '#submit' => array('peerjs_chat_form_delete_submit'),
    );
  }

  return $form;
}

/**
 * Validation handler for peerjs_chat_add_form form.
 */
function peerjs_chat_form_validate($form, &$form_state) {
  field_attach_form_validate('peerjs_chat', $form_state['values']['peerjs_chat'], $form, $form_state);
}

/**
 * Submit handler for peerjs_chat_add_form form.
 */
function peerjs_chat_form_submit($form, &$form_state) {

  $entity = entity_ui_controller('peerjs_chat')->entityFormSubmitBuildEntity($form, $form_state);

  if ($entity->is_new = isset($entity->is_new) ? $entity->is_new : 0){
    $entity->created = time();
  }

  $entity->save();

  $form_state['redirect'] = $entity->uri();
}

/**
 * Delete handler for peerjs_chat_form form.
 */
function peerjs_chat_form_delete_submit($form, &$form_state) {
  $form_state['redirect'] = array(
    'peerjs_chat/' . $form_state['peerjs_chat']->cid . '/delete',
    array(
      'query' => array(
        'destination' => '<front>',
      ),
    ),
  );
}
